@@ -39,7 +39,7 @@ class NLPDataset:
     def _text_transform(self, text: tf.Tensor) -> List[str]:
         return self.text_cutter(text.numpy().decode('utf-8'))
 
-    def _label_transform(self, label: tf.Tensor) -> List[str]:
+    def _label_transform(self, label: tf.Tensor) -> str:
         return label.numpy().decode('utf-8')
 
     def _transform(self, dataset: tf.data.Dataset) -> tf.data.Dataset:
