@@ -2,10 +2,10 @@ from .mlp import MLPLayer
 from .lstmp import LSTMPCell, LSTMP
 from .multi_lstmp import MultiLSTMP
 from .bert_tokenization import BertTokenizationLayer
-from .bert_layer import BertLayer, BertPreprocessingLayer
+from .bert_layer import BertLayer, BertPreprocessingLayer, AlbertLayer
 
 
 __all__ = [
     "MLPLayer", "LSTMPCell", "LSTMP", "MultiLSTMP",
-    "BertTokenizationLayer", "BertLayer", "BertPreprocessingLayer"
+    "BertTokenizationLayer", "BertLayer", "BertPreprocessingLayer", "AlbertLayer"
 ]
