@@ -5,6 +5,7 @@ import tempfile
 import tensorflow as tf
 from tensorflow.keras.initializers import TruncatedNormal
 from tensorflow.keras.layers import InputSpec
+from tensorflow.keras.layers.experimental.preprocessing import TextVectorization
 
 from official.modeling import activations
 from official.nlp.modeling import layers
@@ -12,6 +13,7 @@ from official.nlp.bert.configs import BertConfig
 from official.nlp.albert.configs import AlbertConfig
 import tensorflow_text as tftext
 
+from .bert_tokenization import BertTokenizationLayer
 from .utils import (
     convert_bert_checkpoint, create_bert_model,
     convert_albert_checkpoint, create_albert_model,
@@ -32,6 +34,7 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
         vocab: Sequence[str],
         cls_token: str = "[CLS]",
         sep_token: str = "[SEP]",
+        use_char: bool = False,
         **kwargs
     ) -> None:
         vocab: List = list(vocab)
@@ -42,17 +45,28 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
         if sep_token not in vocab:
             vocab.append(sep_token)
         self.vocab = vocab
-        self.tokenizer = tftext.BertTokenizer(
-            tf.lookup.StaticVocabularyTable(
-                tf.lookup.KeyValueTensorInitializer(
-                    vocab,
-                    list(range(len(vocab))),
-                    key_dtype=tf.string,
-                    value_dtype=tf.int64
-                ),
-                1
+        self.use_char = use_char
+        if self.use_char:
+            vocab[100] = "unk"  # magic number is the index of [UNK]
+            self.tokenizer = TextVectorization(
+                max_tokens=len(vocab),
+                standardize=None,
+                split=BertTokenizationLayer(cls_token=cls_token,
+                                            sep_token=sep_token)
+            )
+            self.tokenizer.set_vocabulary(vocab[2:])
+        else:
+            self.tokenizer = tftext.BertTokenizer(
+                tf.lookup.StaticVocabularyTable(
+                    tf.lookup.KeyValueTensorInitializer(
+                        vocab,
+                        list(range(len(vocab))),
+                        key_dtype=tf.string,
+                        value_dtype=tf.int64
+                    ),
+                    1
+                )
             )
-        )
         for i, token in enumerate(vocab):
             if token == cls_token:
                 self.cls_id = i
@@ -61,23 +75,29 @@ class BertPreprocessingLayer(tf.keras.layers.Layer):
         super().__init__(**kwargs)
 
     def call(self, inputs: tf.Tensor) -> tf.Tensor:
-        token_ids = self.tokenizer.tokenize(inputs)
-        flatten_ids = token_ids.merge_dims(-2, -1)
-        cls_ids = tf.reshape(
-            tf.tile(tf.constant([self.cls_id], dtype=tf.int64), [token_ids.nrows()]),
-            [token_ids.nrows(), 1]
-        )
-        sep_ids = tf.reshape(
-            tf.tile(tf.constant([self.sep_id], dtype=tf.int64), [token_ids.nrows()]),
-            [token_ids.nrows(), 1]
-        )
-        ids = tf.concat([cls_ids, flatten_ids, sep_ids], axis=1)
-        return ids.to_tensor(0)
+        if self.use_char:
+            return self.tokenizer(inputs)
+        else:
+            token_ids = self.tokenizer.tokenize(inputs)
+            flatten_ids = token_ids.merge_dims(-2, -1)
+            cls_ids = tf.reshape(
+                tf.tile(tf.constant([self.cls_id], dtype=tf.int64),
+                        [token_ids.nrows()]),
+                [token_ids.nrows(), 1]
+            )
+            sep_ids = tf.reshape(
+                tf.tile(tf.constant([self.sep_id], dtype=tf.int64),
+                        [token_ids.nrows()]),
+                [token_ids.nrows(), 1]
+            )
+            ids = tf.concat([cls_ids, flatten_ids, sep_ids], axis=1)
+            return ids.to_tensor(0)
 
     def get_config(self) -> Dict[str, Any]:
         return {
             **super().get_config(),
             "vocab": self.vocab,
+            "use_char": self.use_char,
             "cls_token": self.cls_token,
             "sep_token": self.sep_token
         }
