@@ -12,7 +12,7 @@ class MLPLayer(Layer):
         hidden_size: int = 256,
         output_size: int = 1,
         activation: str = "tanh",
-        l2: int = 0.01,
+        # l2: int = 0.01,
         name: str = "mlp",
         **kwargs
     ) -> None:
@@ -33,8 +33,8 @@ class MLPLayer(Layer):
                 self.dense_layers.append(Dense(
                     hidden_size,
                     activation=_activation,
-                    kernel_regularizer=tf.keras.regularizers.L2(l2=l2),
-                    bias_regularizer=tf.keras.regularizers.L2(l2=l2),
+                    # kernel_regularizer=tf.keras.regularizers.L2(l2=l2),
+                    # bias_regularizer=tf.keras.regularizers.L2(l2=l2),
                     name="dense-%d" % i
                 ))
                 self.batchnorm_layers.append(BatchNormalization())
