@@ -3,7 +3,7 @@ from functools import partial
 import tensorflow as tf
 from tensorflow.python.keras.losses import LossFunctionWrapper
 import tensorflow.keras.backend as K
-
+from sknlp.typing import WeightInitializer
 
 
 def soft_fscore(activation_function, y_true, y_pred, from_logits=False, label_smoothing=0):
@@ -37,3 +37,26 @@ class SoftFScoreLoss(LossFunctionWrapper):
             from_logits=from_logits,
             label_smoothing=label_smoothing)
         self.from_logits = from_logits
+
+
+from tensorflow.keras.layers import Layer
+
+
+class CrfLosts(Layer):
+
+    def __init__(
+        self,
+        output_size: int = 1,
+        kernel_initializer: WeightInitializer = 'glorot_uniform',
+        name: str = "crf",
+        **kwargs
+    ) -> None:
+        super().__init__(name=name, **kwargs)
+        self.output_size = output_size
+
+    def build(self, input_shape):
+        self.kernel = self.add_weight(
+            shape=(self.output_size, self.output_size),
+            name='kernel',
+            initializer=self.kernel_initializer,
+        )
