@@ -105,7 +105,11 @@ class BaseNLPModel:
         d = os.path.join(directory, name, version)
 
         model = tf.keras.models.model_from_json(
-            self._model.to_json(), custom_objects=self.get_custom_objects()
+            self._model.to_json(), 
+            custom_objects={
+                **self.get_custom_objects(), 
+                "TruncatedNormal": tf.keras.initializers.TruncatedNormal,
+            }
         )
         model.set_weights(self._model.get_weights())
         model.save(d, include_optimizer=False, save_format="tf")
@@ -113,12 +117,6 @@ class BaseNLPModel:
 
     def get_config(self) -> Dict[str, Any]:
         return {
-            "inputs": self.input_names,
-            "input_types": self.input_types,
-            "input_shapes": self.input_shapes,
-            "outputs": self.output_names,
-            "output_types": self.output_types,
-            "output_shapes": self.output_shapes,
             "max_sequence_length": self.max_sequence_length,
             "sequence_length": self.sequence_length,
             "name": self._name
