@@ -5,7 +5,7 @@ from tensorflow.keras.layers import Dropout
 import pandas as pd
 
 from sknlp.layers import (
-    MLPLayer, BertLayer, AlbertLayer, BertPreprocessingLayer
+    MLPLayer, BertLayer, AlbertLayer, BertPreprocessingLayer, BertTokenizationLayer
 )
 from sknlp.vocab import Vocab
 from sknlp.data import BertClassificationDataset
@@ -77,5 +77,5 @@ class BertClassifier(DeepClassifier):
             "BertLayer": BertLayer,
             "AlbertLayer": AlbertLayer,
             "BertPreprocessingLayer": BertPreprocessingLayer,
-            "TruncatedNormal": tf.keras.initializers.TruncatedNormal,
+            "BertTokenizationLayer": BertTokenizationLayer,
         }
