@@ -253,3 +253,9 @@ class SupervisedNLPModel(BaseNLPModel):
         super().export(directory, name, version)
         d = os.path.join(directory, name, version)
         self._text2vec.save_vocab(d)
+
+    def get_custom_objects(self) -> Dict[str, Any]:
+        return {
+            **super().get_custom_objects(),
+            "AdamW": tfa.optimizers.AdamW
+        }
\ No newline at end of file
